@@ -1,5 +1,5 @@
 ## compute AUC
-AUC <- function(x, y, group, switchAUC = TRUE){
+AUC <- function(x, y, group, switchAUC = TRUE, na.rm = TRUE){
     if(missing(y) && missing(group)){
         stop("'y' or 'group' must be specified!")
     }
@@ -11,6 +11,12 @@ AUC <- function(x, y, group, switchAUC = TRUE){
         y <- x[group == 1]
         x <- x[group == 0]
     }
+    if(na.rm){
+        x <- x[!is.na(x)]
+        y <- y[!is.na(y)]
+    }
+    if(all(is.na(x)) || all(is.na(y))) return(NA)
+    
     x <- sort(x)
     y <- sort(y)
     nx <- as.numeric(length(x))
